#######################################################################
#
# NCM component for dblbconfig daemon
#
# Charles Loomis <charles.loomis@cern.ch>
# Version 0.0.2 : 05/12/04 18:20
#
# ** Generated file : do not edit **
#
#######################################################################

package NCM::Component::dblbconfig;

use strict;
use NCM::Component;
use vars qw(@ISA $EC);
@ISA = qw(NCM::Component);
$EC=LC::Exception::Context->new->will_store_all;
use NCM::Check;
use File::Copy;

use EDG::WP4::CCM::Element;


local(*DTA);


##########################################################################
sub Configure($$@) {
##########################################################################
    
    my ($self, $config) = @_;

    # Define paths for convenience. 
    my $base = "/software/components/dblbconfig";
    my $edgpath = "/system/edg/config/EDG_LOCATION";
    my $edgvarpath = "/system/edg/config/EDG_LOCATION_VAR";

    # Default location for EDG software.
    my $edgloc = "/opt/edg";
    if ($config->elementExists($edgpath)) {
        $edgloc = $config->getValue($edgpath);
    }

    # Default location for EDG var area.
    my $varloc = "$edgloc/var";
    if ($config->elementExists($edgvarpath)) {
        $varloc = $config->getValue($edgvarpath); 
    }

    # Ensure that the configuration path exists.
    my $cfgpath = "$edgloc/etc";
    mkpath($cfgpath,0,0755) unless (-d $cfgpath);
    unless (-d $cfgpath) {
	$self->error("$cfgpath can't be created");
	return 1;
    }

    # Save the date.
    my $date = localtime();

    # Create the sqlFile configuration. 
    my $contents = "#\n# Generated by dblbconfig on $date\n#\n";

    my $dbName = $config->getValue("$base/dbName");
    my $dbUser = $config->getValue("$base/dbUser");
    my $dbPassword = $config->getValue("$base/dbPassword");
    my $dbPasswordFlag = $config->getValue("$base/dbPasswordFlag");

    $contents .= "CREATE DATABASE $dbName;\n";
    if ($dbPasswordFlag eq 'yes') {
	$contents .= "GRANT ALL PRIVILEGES ON $dbName.* TO $dbUser\@localhost IDENTIFIED BY '$dbPassword';\n";
    } else {
	$contents .= "GRANT ALL PRIVILEGES ON $dbName.* TO $dbUser\@localhost IDENTIFIED BY '';\n";
    }
    $contents .= "USE $dbName;\n";

    # Create/update the configuration file.
    my $fname = "$cfgpath/" . $config->getValue("$base/sqlFile");
    $self->createConfig($fname, $contents);

    # Create the arrivedSQLFile configuration. 
    my $srcfile = "$cfgpath/edg-wll-add-arrived.sql.template";
    my $dstfile = "$cfgpath/" . $config->getValue("$base/arrivedSQLFile");
    copy($srcfile, $dstfile);
    if ($?) {
	$self->error("problem copying $srcfile to $dstfile");
    }

    # Create the srvstatSQLFile configuration. 
    $srcfile = "$cfgpath/edg-wll-add-srvstat.sql.template";
    $dstfile = "$cfgpath/" . $config->getValue("$base/srvstatSQLFile");
    copy($srcfile, $dstfile);
    if ($?) {
	$self->error("problem copying $srcfile to $dstfile");
    }

    # Create the aclsSQLFile configuration. 
    $srcfile = "$cfgpath/edg-wll-add_acls.sql.template";
    $dstfile = "$cfgpath/" . $config->getValue("$base/aclsSQLFile");
    copy($srcfile, $dstfile);
    if ($?) {
	$self->error("problem copying $srcfile to $dstfile");
    }

    # Check that the server.sql file is present. 
    unless (-e "$cfgpath/server.sql") {
	$self->warn("$cfgpath/server.sql does not exist");
    }

    return 1;
}

sub createConfig {

    my ($self, $fname, $contents) = @_;

    # Now just create the new configuration file.  Be careful to save
    # a backup of the previous file if necessary. 
    if ( ! -e $fname ) {
        
        # Configuration file doesn't exist yet.  Create it. 
        open CONF, ">$fname";
        print CONF $contents;
        close (CONF);
        $self->log("$fname created");
        
    } else {
        
        # Already exists. Make backup and create new file. 
        my $result = LC::Check::file( $fname,
                                      backup => ".old",
                                      contents => $contents,
                                      );
        $self->log("$fname updated") if $result;
    }
};


1;      # Required for PERL modules
